<?php
/**
*
* @package hjw easylanguagechange Extension
* @copyright (c) 2022 hjw
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace hjw\easylanguagechange\event;

/**
* @ignore
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class main_listener implements EventSubscriberInterface
{
	public static function getSubscribedEvents()
	{
		return array(
			'core.user_setup'		=> 'language_change',
			'core.page_header'		=> 'language_flags',
		);
	}

	/** @var \phpbb\user */
	protected $user;

	/** @var \phpbb\config\config */
	protected $config;

	/** @var \phpbb\db\driver\driver_interface */
	protected $db;

	/** @var \phpbb\request\request_interface */
	protected $request;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var string phpbb root path */
	protected $phpbb_root_path;

	/** @var string phpbb root path */
	protected $phpbb_php_ext;

	/**
	* Constructor
	*
	* @param \phpbb\user			$this->user
	*/

	public function __construct(\phpbb\user $user, \phpbb\config\config $config,
	\phpbb\db\driver\driver_interface $db, \phpbb\request\request $request,
	\phpbb\template\template $template, $phpbb_table_prefix, $phpbb_root_path, $phpbb_php_ext)
	{
		$this->user = $user;
		$this->config = $config;
		$this->request = $request;
		$this->template = $template;
		$this->ext_root_path = $phpbb_root_path;
		$this->ext_path = $phpbb_root_path . 'ext/hjw/easylanguagechange/';
		$this->phpex = $phpbb_php_ext;
		$this->db = $db;
		$this->table_prefix = $phpbb_table_prefix;
	}

	public function language_change($event)
	{
		if (!strstr($this->request->variable('REQUEST_URI', '', false,\phpbb\request\request_interface::SERVER),'adm/index.php'))
		{
			$lang = $this->request->variable('lang',$this->request->variable($this->config['cookie_name'] . '_lang', '', false,\phpbb\request\request_interface::COOKIE));
			if ($this->user->data['username'] == 'Anonymous' && !$lang)
			{
				$lang_list = '';
				$sql = 'SELECT *
					FROM ' . LANG_TABLE;
				$result = $this->db->sql_query($sql);
				while ($row = $this->db->sql_fetchrow($result))
				{
					$lang_list .= $row['lang_iso'] . ' ';
				}
				$languages = explode(',' , $this->request->variable('HTTP_ACCEPT_LANGUAGE', '', false,\phpbb\request\request_interface::SERVER));
				$language = '';
				$max = 0;
				foreach ($languages as $language)
				{
					if (!strstr($language,'='))
					{
						$language .= ';q=1.0';
					}
					$m = explode('=', $language);
					if ($m[1] > $max)
					{
						$l =  explode(';',$language);
						$l[0] = strtolower(strtr($l[0], '-', '_'));
						if (strstr($l[0],'_'))
						{
							$le = explode('_',$l[0]);
							if ($le[0] == $le[1])
							{
								$l[0] = $le[0];
							}
						}
						if ($lang_list && $l[0])
						{
							if (strstr($lang_list,$l[0]))
							{
								$lang = $l[0];
								$max = $m[1];
							}
						}
					}
				}
				if ($lang == 'de' && !strstr($lang_list,$lang . ' '))
				{
					$lang = 'de_x_sie';
				}
			}
			else
			{
				if ($this->request->variable('lang',''))
				{
					$event['user_lang_name'] = $this->request->variable('lang','');
					$sql = 'UPDATE ' . $this->table_prefix . 'users' . '
							SET user_lang = "' . $this->request->variable('lang','') . '"
								WHERE user_id = ' . (int) $this->user->data['user_id'];
					$result = $this->db->sql_query($sql);
				}
			}
			$this->user->set_cookie('lang', $lang, time()+60*60*24*365);
		}
	}

	public function language_flags()
	{
		$lang = $this->request->variable('lang' ,$this->request->variable($this->config['cookie_name'] . '_lang', '', false,\phpbb\request\request_interface::COOKIE));
		if (!$lang)
		{
			$lang = $this->user->data['user_lang'];
		}
		$sql = 'SELECT *
				FROM ' . $this->table_prefix . 'lang' . '
					ORDER by lang_iso';
		$lang_result = $this->db->sql_query($sql);
		while ($lang_row = $this->db->sql_fetchrow($lang_result))
		{
			$this->template->assign_block_vars('flags', array(
				'ACTIVE'		=> ($lang_row['lang_iso'] == $lang) ? true : false,
				'NAME'			=> $lang_row['lang_local_name'],
				'VALUE'			=> $lang_row['lang_iso'],
			));
			if ($lang_row['lang_iso'] == $lang)
			{
				$this->template->assign_vars(array(
					'LANG_ACTIVE'	=> ($lang_row['lang_iso'] == 'de_x_sie') ? 'DE' : strtoupper($lang_row['lang_iso']),
					'LANG_ACTIVE_NAME'	=> $lang_row['lang_local_name'],
					'FLAG_ACTIVE'		=> $lang_row['lang_iso'] . '.png',
				));
			}
			else
			{
				$this->template->assign_block_vars('lang', array(
					'LANG'		=> $lang_row['lang_iso'],
					'LANG_NAME'	=> $lang_row['lang_local_name'],
					'FLAG'		=> $lang_row['lang_iso'] . '.png',
				));
			}

		}
		$this->template->assign_vars(array(
			'FLAGS'				=> $this->config['easy_language_change_flags'],
		));
	}
}
